==> genphen_1.10.3.zip: genphen/NEWS.Rd <==
\name{NEWS}
\title{News for Package 'genphen'}




\section{Changes in genphen version 1.10.1 (2019-03-03)}{

  \subsection{Changes:}{
    \itemize{
      \item Multiple traits (quantitative and dichotomous) handled
      \item Speed-up
      \item Bayesian hierarchical model implemented => multiple comparison solved
      \item Transition from effect size metrics to GLMs
      \item Posterior predictive checks automatic
      \item Retrospective power analysis available
      \item Stan model debugging possible
      \item Multicore speedup
      \item Phylogenetic bias quantification
      \item Data reduction with diagnostics procedure based on random forest
    }
  }

  \subsection{To do:}{
    \itemize{
      \item Include a CONFIG file to change internal parameters
      \item Add practical examples where genphen has been used.
      \item Implement modules for data augmentation
      \item Update todo after data augmentation
    }
  }
}






\section{Changes in genphen version 1.8 (2018-08-20)}{

  \subsection{Changes:}{
    \itemize{
      \item Multi-core support, dramatic speed-up of run-time
    }
  }

  \subsection{To do:}{
    \itemize{
      \item Add practical examples where genphen has been used.
      \item Implement modules for data augmentation
      \item Update todo after data augmentation
    }
  }
}



\section{Changes in genphen version 1.7 (2018-01-20}{

  \subsection{Introduction:}{
    \itemize{
      \item Additional functions are added sporadically.
      \item This news file reports changes that have been made as the package
      has been developed.
    }
  }

  \subsection{Changes:}{
    \itemize{
      \item Bayesian inference using stan (rstan package)
      \item Two bayesian inference methods to support both continuous and
      dichotomous phenotypes
      \item Additional genotype-phenotype association metrics added
      \item Posterior predictive checks implemented
      \item Procedure for data reduction (runDiagnostics) added
      \item Tutorial updated
      \item Simple procedure for phylogenetic bias estimation implemented
      \item Retrospective power analysis module
    }
  }

  \subsection{To do:}{
    \itemize{
      \item Add practical examples where genphen has been used.
      \item Implement modules for data augmentation
      \item Update todo after data augmentation
    }
  }
}

==> genphen_1.17.0.zip: genphen/NEWS.Rd <==
\name{NEWS}
\title{News for Package 'genphen'}




\section{Changes in genphen version 1.9 (2018-10-20)}{

  \subsection{Changes:}{
    \itemize{
      \item multi-trait analyses
      \item Bayesian hierarchical model implemented => multiple comparison solved
      \item Transition from effect size metrics to GLMs
      \item Posterior predictive checks automatic
      \item Retrospective power analysis available
      \item Stan model debugging possible
      \item Multicore speedup
      \item Phylogenetic bias quantification
      \item Data reduction with diagnostics procedure based on random forest
    }
  }

  \subsection{To do:}{
    \itemize{
      \item Include a CONFIG file to change internal parameters
      \item Add practical examples where genphen has been used.
      \item Implement modules for data augmentation
      \item Update todo after data augmentation
    }
  }
}






\section{Changes in genphen version 1.8 (2018-08-20)}{

  \subsection{Changes:}{
    \itemize{
      \item Multi-core support, dramatic speed-up of run-time
    }
  }

  \subsection{To do:}{
    \itemize{
      \item Add practical examples where genphen has been used.
      \item Implement modules for data augmentation
      \item Update todo after data augmentation
    }
  }
}



\section{Changes in genphen version 1.7 (2018-01-20}{

  \subsection{Introduction:}{
    \itemize{
      \item Additional functions are added sporadically.
      \item This news file reports changes that have been made as the package
      has been developed.
    }
  }

  \subsection{Changes:}{
    \itemize{
      \item Bayesian inference using stan (rstan package)
      \item Two bayesian inference methods to support both continuous and
      dichotomous phenotypes
      \item Additional genotype-phenotype association metrics added
      \item Posterior predictive checks implemented
      \item Procedure for data reduction (runDiagnostics) added
      \item Tutorial updated
      \item Simple procedure for phylogenetic bias estimation implemented
      \item Retrospective power analysis module
    }
  }

  \subsection{To do:}{
    \itemize{
      \item Add practical examples where genphen has been used.
      \item Implement modules for data augmentation
      \item Update todo after data augmentation
    }
  }
}
